"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CodeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code"]) -> None: ...

global___CodeReq = CodeReq

class CodeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CodeReply = CodeReply

class ProbeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    buvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        buvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid", b"buvid", "mid", b"mid"]) -> None: ...

global___ProbeReq = ProbeReq

class ProbeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    timestamp: builtins.int
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        timestamp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "timestamp", b"timestamp"]) -> None: ...

global___ProbeReply = ProbeReply

class ProbeStreamReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    sequence: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        sequence: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "sequence", b"sequence"]) -> None: ...

global___ProbeStreamReq = ProbeStreamReq

class ProbeStreamReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEQUENCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    sequence: builtins.int
    """"""
    timestamp: builtins.int
    """"""
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        sequence: builtins.int = ...,
        timestamp: builtins.int = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "sequence", b"sequence", "timestamp", b"timestamp"]) -> None: ...

global___ProbeStreamReply = ProbeStreamReply

class ProbeSubReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUVID_FIELD_NUMBER: builtins.int
    buvid: builtins.int
    """"""
    def __init__(
        self,
        *,
        buvid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid", b"buvid"]) -> None: ...

global___ProbeSubReq = ProbeSubReq

class ProbeSubReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        message_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id", b"message_id"]) -> None: ...

global___ProbeSubReply = ProbeSubReply
